@@ -7,7 +7,7 @@
 ;;;; Author:   Kevin M. Rosenberg
 ;;;; Created:  Feb 2002
 ;;;;
-;;;; $Id: mysql-loader.lisp 11102 2006-09-06 12:51:12Z kevin $
+;;;; $Id: mysql-loader.lisp 11727 2007-06-17 19:39:07Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2002-2004 by Kevin M. Rosenberg
 ;;;;
@@ -40,9 +40,14 @@ set to the right path before compiling or loading the system.")
 (defmethod clsql-sys:database-type-load-foreign ((database-type (eql :mysql)))
   (clsql:push-library-path
    (make-pathname :directory clsql-mysql-system::*library-file-dir*))
-  (clsql-uffi:find-and-load-foreign-library *mysql-library-candidate-names*
-                                            :module "mysql"
-                                            :supporting-libraries *mysql-supporting-libraries*)
+
+  ;; since clsql-mysql is dynamically linked to libmysqlclient, do not need to
+  ;; load libmysqlclient directly
+  ;;
+  ;;(clsql-uffi:find-and-load-foreign-library *mysql-library-candidate-names*
+  ;;                                          :module "mysql"
+  ;;                                          :supporting-libraries *mysql-supporting-libraries*)
+
   (clsql-uffi:find-and-load-foreign-library *clsql-mysql-library-candidate-names*
                                             :module "clsql-mysql"
                                             :supporting-libraries *mysql-supporting-libraries*)
