@@ -8,7 +8,7 @@
 ;;;;                Original code by Pierre R. Mai 
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: postgresql-api.lisp 11231 2006-10-16 19:28:44Z kevin $
+;;;; $Id: postgresql-api.lisp 11418 2006-12-31 01:36:25Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;; and Copyright (c) 1999-2001 by Pierre R. Mai
@@ -18,7 +18,7 @@
 ;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
 ;;;; *************************************************************************
 
-(in-package #:postgresql)
+(in-package #:pgsql)
 
 
 ;;;; This file implements as little of the FFI bindings to the
