@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: postgresql-package.lisp 11228 2006-10-16 19:07:38Z kevin $
+;;;; $Id: postgresql-package.lisp 11418 2006-12-31 01:36:25Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -18,8 +18,9 @@
 
 (in-package #:cl-user)
 
-(defpackage #:postgresql
-    (:nicknames #:pgsql)
+(defpackage #:pgsql
+    #-(and :lispworks (not :lispworks4))
+    (:nicknames #:postgresql)
     (:use #:cl #:clsql-uffi)
     (:export
      #:pgsql-oid
