@@ -7,7 +7,7 @@
 ;;;;
 ;;;; Copyright (c) 2001-2006 Kevin Rosenberg and (c) 1999-2001 Pierre R. Mai
 ;;;;
-;;;; $Id: loop-extension.lisp 11060 2006-08-30 08:58:47Z kevin $
+;;;; $Id: loop-extension.lisp 11418 2006-12-31 01:36:25Z kevin $
 ;;;; *************************************************************************
 
 (in-package #:clsql-sys)
@@ -141,7 +141,7 @@
 (defun clsql-loop-method (method-name iter-var iter-var-data-type
 			  prep-phrases inclusive? allowed-preps
 			  method-specific-data)
-  (declare (ignore method-name inclusive? allowed-preps method-specific-data))
+  (declare (ignore method-name iter-var-data-type inclusive? allowed-preps method-specific-data))
   (let ((in-phrase nil)
 	(from-phrase nil))
     (loop for (prep . rest) in prep-phrases
