@@ -1,7 +1,7 @@
 ;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
 ;;;; *************************************************************************
 ;;;;
-;;;; $Id: metaclasses.lisp 11094 2006-09-05 03:31:01Z kevin $
+;;;; $Id: metaclasses.lisp 11422 2006-12-31 18:42:41Z kevin $
 ;;;;
 ;;;; CLSQL metaclass for standard-db-objects created in the OODDL.
 ;;;;
@@ -429,8 +429,7 @@ implementations."
 
 (defmethod initialize-instance :around ((obj view-class-direct-slot-definition)
                                         &rest initargs)
-  (do* ((saved-initargs initargs)
-        (parsed (list obj))
+  (do* ((parsed (list obj))
         (name (first initargs) (first initargs))
         (val (second initargs) (second initargs))
         (type nil)
