@@ -1,7 +1,7 @@
 ;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
 ;;;; *************************************************************************
 ;;;;
-;;;; $Id: time.lisp 10922 2006-05-03 14:39:10Z kevin $
+;;;; $Id: time.lisp 11094 2006-09-05 03:31:01Z kevin $
 ;;;;
 ;;;; A variety of structures and function for creating and
 ;;;; manipulating dates, times, durations and intervals for
@@ -406,7 +406,9 @@
 );eval-when
 
 (defmacro wrap-time-for-date (time-func &key (result-func))
-  (let ((date-func (intern (replace-string (symbol-name time-func) "TIME" "DATE"))))
+  (let ((date-func (intern (replace-string (symbol-name time-func) 
+                                           (symbol-name-default-case "TIME")
+                                           (symbol-name-default-case "DATE")))))
     `(defun ,date-func (number &rest more-numbers)
       (let ((result (apply #',time-func (mapcar #'date->time (cons number more-numbers)))))
 	,(if result-func
