@@ -3,9 +3,9 @@
 ;;;; File:    test-connection.lisp
 ;;;; Authors: Marcus Pearce <m.t.pearce@city.ac.uk>, Kevin Rosenberg
 ;;;; Created: 30/03/2004
-;;;; Updated: $Id: test-connection.lisp 9336 2004-05-13 06:55:48Z kevin $
+;;;; Updated: $Id: test-connection.lisp 11727 2007-06-17 19:39:07Z kevin $
 ;;;;
-;;;; Tests for CLSQL database connections. 
+;;;; Tests for CLSQL database connections.
 ;;;;
 ;;;; This file is part of CLSQL.
 ;;;;
@@ -18,7 +18,7 @@
 
 (setq *rt-connection*
       '(
-	
+
 (deftest :connection/1
     (let ((database (clsql:find-database
                      (clsql:database-name clsql:*default-database*)
@@ -27,13 +27,26 @@
   t)
 
 (deftest :connection/2
-    (clsql-sys::string-to-list-connection-spec 
+    (clsql-sys::string-to-list-connection-spec
      "localhost/dbname/user/passwd")
   ("localhost" "dbname" "user" "passwd"))
 
 (deftest :connection/3
-    (clsql-sys::string-to-list-connection-spec 
+    (clsql-sys::string-to-list-connection-spec
      "dbname/user@hostname")
   ("hostname" "dbname" "user"))
 
+(deftest :db/1
+    (let ((inner-db-same)
+          (original-a)
+          (outer-db-unchanged))
+      (print "test-connection-spec")
+      (print *test-connection-spec*)
+      (clsql:with-database (a '*test-connection-spec* :database-type *test-connection-db-type*)
+        (setq original-a a)
+        (clsql:with-database (b '*test-connection-spec* :database-type *test-connection-db-type*)
+          (setq inner-db-same (eq a b)))
+        (setq outer-db-unchanged (eq a original-a))))
+  t t)
+
 ))
