@@ -7,7 +7,7 @@
 ;;;; Author:   Kevin M. Rosenberg
 ;;;; Created:  Mar 2002
 ;;;;
-;;;; $Id: clsql-uffi-loader.lisp 11102 2006-09-06 12:51:12Z kevin $
+;;;; $Id: clsql-uffi-loader.lisp 11657 2007-04-25 18:14:36Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2002-2004 by Kevin M. Rosenberg
 ;;;;
@@ -28,16 +28,16 @@ well as any of the filenames in any of the clsql:*foreign-library-search-paths*"
 	       (uffi:load-foreign-library testpath
 					  :module module
 					  :supporting-libraries supporting-libraries)
-	     (error (c) (warn "~A" c) nil))))
+	     (error nil)))) ;(c) (warn "~A" c) nil))))
     (or
      (loop for type in (uffi:foreign-library-types)
 	   thereis
 	   (loop for name in filenames
 		 for pn = (make-pathname :name name :type type)
 		 thereis (or
+                          (try-load pn)
 			  (loop for search-path in clsql:*foreign-library-search-paths*
-				thereis (try-load (merge-pathnames pn search-path)))
-			  (try-load pn))))
+				thereis (try-load (merge-pathnames pn search-path))))))
      (when errorp
        (error "Couldn't load foreign librar~@P ~{~S~^, ~}. (searched ~S)"
 	      (length filenames) filenames
